summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorspuligil <spuligil@codeaurora.org>2019-11-26 06:00:51 -0800
committerspuligil <spuligil@codeaurora.org>2019-11-26 06:00:51 -0800
commit22c78fef2f5640212f2f25b9a643b8f110108bb5 (patch)
tree469019908bb8c2ede77f8f58a121b858c29aee81
parente4fee39771032d10af340bfb7be87263dc2058a7 (diff)
fw-api: CL 8847485 - update fw common interface files
WMI: add flags to specify whether host should create NAN vdev also correct the value for WMI_SERVICE_NAN_NDI_SAP_SAP_SCC_SUPPORT Change-Id: I5448d5f1e8d4597548de9064e13d7e2b99ae45c9 CRs-Fixed: 2262693
-rwxr-xr-xfw/wmi_services.h3
-rwxr-xr-xfw/wmi_unified.h1
-rwxr-xr-xfw/wmi_version.h2
3 files changed, 4 insertions, 2 deletions
diff --git a/fw/wmi_unified.h b/fw/wmi_unified.h
index 5ed4c96c5c03..adabab8c4e1b 100755
--- a/fw/wmi_unified.h
+++ b/fw/wmi_unified.h
@@ -18095,6 +18095,7 @@ typedef struct {
A_UINT32 mac_id; /* MAC ID associated with NAN primary discovery channel; Valid only for NAN enable resp message identified by NAN_MSG_ID_ENABLE_RSP */
A_UINT32 status:1; /** This bit when set to 0 indicates status is successful; Valid only for NAN enable resp message identified by NAN_MSG_ID_ENABLE_RSP */
A_UINT32 reserved:31;
+ A_UINT32 vdev_id; /** Unique id identifying the vdev with type OPMODE_NAN; Valid only for NAN enable resp message identified by NAN_MSG_ID_ENABLE_RSP */
} wmi_nan_event_info_PROTOTYPE;
#define wmi_nan_event_info wmi_nan_event_info_PROTOTYPE
diff --git a/fw/wmi_version.h b/fw/wmi_version.h
index 9c68f9f86c4c..c30fe3235472 100755
--- a/fw/wmi_version.h
+++ b/fw/wmi_version.h
@@ -36,7 +36,7 @@
#define __WMI_VER_MINOR_ 0
/** WMI revision number has to be incremented when there is a
* change that may or may not break compatibility. */
-#define __WMI_REVISION_ 741
+#define __WMI_REVISION_ 742
/** The Version Namespace should not be normally changed. Only
* host and firmware of the same WMI namespace will work
diff --git a/fw/wmi_services.h b/fw/wmi_services.h
index 459f7bc27ceb..a0a396afbb9b 100755
--- a/fw/wmi_services.h
+++ b/fw/wmi_services.h
@@ -417,7 +417,8 @@ typedef enum {
WMI_SERVICE_STA_BSS_MAX_IDLE_TIME = 227, /* Indicate FW supports BSS Max Idle time feature via WMI_VDEV_BSS_MAX_IDLE_TIME_CMDID */
WMI_SERVICE_BIP_CIPHER_SUPPORT = 228, /* FW supports new BIP_CIPHER suites (WMI_CIPHER_BIP_xxx) */
WMI_SERVICE_BW_165MHZ_SUPPORT = 229, /* Indicate FW supports bandwidth 165MHz (i.e. 6 GHz in addition to 2.4 and 5) */
- WMI_SERVICE_NAN_NDI_SAP_SAP_SCC_SUPPORT = 229, /* Support SAP + SAP + NAN discovery + NDI concurrency in SCC mode */
+ WMI_SERVICE_NAN_NDI_SAP_SAP_SCC_SUPPORT = 230, /* Support SAP + SAP + NAN discovery + NDI concurrency in SCC mode */
+ WMI_SERVICE_NAN_VDEV_SUPPORT = 231, /* indicates firmware is dependent on host to create NAN vdev */
/******* ADD NEW SERVICES HERE *******/